Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1810)

Unified Diff: tools/rebaseline.py

Issue 18324018: rebaseline.py: use specified configs/tests as a FILTER over actually-run tests (Closed) Base URL: http://skia.googlecode.com/svn/trunk/
Patch Set: sync_to_r9955 Created 7 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | tools/rebaseline_imagefiles.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools/rebaseline.py
===================================================================
--- tools/rebaseline.py (revision 9955)
+++ tools/rebaseline.py (working copy)
@@ -87,16 +87,13 @@
# summary of results; typically "actual-results.json"
# tests: list of tests to rebaseline, or None if we should rebaseline
# whatever files the JSON results summary file tells us to
# configs: which configs to run for each test; this should only be
# specified if the list of tests was also specified (otherwise,
# the JSON file will give us test names and configs)
# add_new: if True, add expectations for tests which don't have any yet
def __init__(self, expectations_root, expectations_filename,
actuals_base_url, actuals_filename,
tests=None, configs=None, add_new=False):
- if configs and not tests:
- raise ValueError('configs should only be specified if tests ' +
- 'were specified also')
self._expectations_root = expectations_root
self._expectations_filename = expectations_filename
self._tests = tests
@@ -215,15 +212,11 @@
'expectations for tests which don\'t have expectations ' +
'yet.')
# TODO(epoger): Add test that exercises --configs argument.
-# TODO(epoger): Once we are only rebaselining JSON files, update the helpstring
-# to indicate that this is a *filter* over the config names that
-# actual-results.json tells us need to be rebaselined.
-# You don't need to specify tests also, etc.
parser.add_argument('--configs', metavar='CONFIG', nargs='+',
help='which configurations to rebaseline, e.g. ' +
- '"--configs 565 8888"; if unspecified, run a default ' +
- 'set of configs. This should ONLY be specified if ' +
- '--tests has also been specified.')
+ '"--configs 565 8888", as a filter over the full set of ' +
+ 'results in ACTUALS_FILENAME; if unspecified, rebaseline ' +
+ '*all* configs that are available.')
# TODO(epoger): The --dry-run argument will no longer be needed once we
# are only rebaselining JSON files.
parser.add_argument('--dry-run', action='store_true',
@@ -245,14 +238,11 @@
'if unspecified, rebaseline all subdirs, same as ' +
'"--subdirs %s"' % ' '.join(sorted(SUBDIR_MAPPING.keys())))
# TODO(epoger): Add test that exercises --tests argument.
-# TODO(epoger): Once we are only rebaselining JSON files, update the helpstring
-# to indicate that this is a *filter* over the test names that
-# actual-results.json tells us need to be rebaselined.
parser.add_argument('--tests', metavar='TEST', nargs='+',
help='which tests to rebaseline, e.g. ' +
- '"--tests aaclip bigmatrix"; if unspecified, then all ' +
- 'failing tests (according to the actual-results.json ' +
- 'file) will be rebaselined.')
+ '"--tests aaclip bigmatrix", as a filter over the full ' +
+ 'set of results in ACTUALS_FILENAME; if unspecified, ' +
+ 'rebaseline *all* tests that are available.')
args = parser.parse_args()
if args.subdirs:
subdirs = args.subdirs
@@ -87,16 +87,13 @@
# tests: list of tests to rebaseline, or None if we should rebaseline
# whatever files the JSON results summary file tells us to
- # configs: which configs to run for each test; this should only be
- # specified if the list of tests was also specified (otherwise,
- # the JSON file will give us test names and configs)
+ # configs: which configs to run for each test, or None if we should
+ # rebaseline whatever configs the JSON results summary file tells
+ # us to
# add_new: if True, add expectations for tests which don't have any yet
def __init__(self, expectations_root, expectations_filename,
« no previous file with comments | « no previous file | tools/rebaseline_imagefiles.py » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698